[svn-commits] mmichelson: branch mmichelson/acl-v6 r275905 - /team/mmichelson/acl-v6/includ...

SVN commits to the Digium repositories svn-commits at lists.digium.com
Tue Jul 13 09:27:31 CDT 2010


Author: mmichelson
Date: Tue Jul 13 09:27:27 2010
New Revision: 275905

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=275905
Log:
Make necessary changes to acl.h

It should be pretty obvious right now that this code does not compile.


Modified:
    team/mmichelson/acl-v6/include/asterisk/acl.h

Modified: team/mmichelson/acl-v6/include/asterisk/acl.h
URL: http://svnview.digium.com/svn/asterisk/team/mmichelson/acl-v6/include/asterisk/acl.h?view=diff&rev=275905&r1=275904&r2=275905
==============================================================================
--- team/mmichelson/acl-v6/include/asterisk/acl.h (original)
+++ team/mmichelson/acl-v6/include/asterisk/acl.h Tue Jul 13 09:27:27 2010
@@ -46,11 +46,11 @@
  * thing public and let users play with them.
  */
 struct ast_ha {
-        /* Host access rule */
-        struct in_addr netaddr;  
-        struct in_addr netmask;
-        int sense;
-        struct ast_ha *next;
+	/* Host access rule */
+	struct ast_sockaddr addr;
+	struct ast_sockaddr netmask;
+	int sense;
+	struct ast_ha *next;
 };
 
 /*!
@@ -111,11 +111,11 @@
  * the one whose sense will be returned.
  *
  * \param ha The head of the list of host access rules to follow
  * \param sin A sockaddr_in whose address is considered when matching rules
  * \retval AST_SENSE_ALLOW The IP address passes our ACL
  * \retval AST_SENSE_DENY The IP address fails our ACL
  */
-int ast_apply_ha(struct ast_ha *ha, struct sockaddr_in *sin);
+int ast_apply_ha(struct ast_ha *ha, struct ast_sockaddr *addr);
 
 /*!
  * \brief Get the IP address given a hostname
@@ -186,7 +186,7 @@
  * \retval -1 Failure. address is filled with 0s
  * \retval 0 Success
  */
-int ast_lookup_iface(char *iface, struct in_addr *address);
+int ast_lookup_iface(char *iface, struct ast_sockaddr *address);
 
 /*!
  * \brief Duplicate the contents of a list of host access rules
@@ -111,11 +111,11 @@
  *
  * \param ha The head of the list of host access rules to follow
- * \param sin A sockaddr_in whose address is considered when matching rules
+ * \param addr An ast_sockaddr whose address is considered when matching rules
  * \retval AST_SENSE_ALLOW The IP address passes our ACL
  * \retval AST_SENSE_DENY The IP address fails our ACL




More information about the svn-commits mailing list